# Description
This graph shows the number of deaths in Japan due to Covid-19.<br>
Data were obtained from the following sites<br>
https://covid19.mhlw.go.jp/public/opendata/deaths_cumulative_daily.csv<br>

# How to install japandeaths
Write the following program in the terminal on your computer.<br>
```
$ pip install japandeaths
```
Then japandeaths will be downloaded.<br>

# How to run jpandeaths
Write the following program in the terminal on your computer.<br>
```
$ japandeaths
```
After executing the above program, the following graph is displayed.<br>
The horizontal axis is a time series and the vertical axis shows the cumulative number of deaths.<br>
We can see that in Japan, about 40,000 people have died from Covid-19.<br>

<img src="https://github.com/i-inose/japandeaths/blob/main/result.png?raw=true">


# Postscript
For this project, we graphed the cumulative number of deaths by Covid-19 and converted them to PyPI.<br>
Although we were able to complete the program quickly, the conversion to PyPI took a very long time.<br>
We hope to continue our research, graphing, and conversion to PyPI not only in the medical field but also in various other fields to provide information to people around the world.<br>
Well, that's about it for this issue. Thank you for reading.<br>
From Izuru Inose
